import React, { useState, useEffect, useCallback, useRef, useMemo } from 'react';
import ModuleTitleWithTabs from '@/pages/Home_v_2504/components/common/ModuleTitleWithTabs';
import SmoothLineChart from '@/components/V2504/SmoothLineChart';
import styles from './index.less';
import { useDataType, useMapState } from '@/pages/Home_v_2504/components/MapStateContext';
import { getEventTrends } from '@/services/CityProblem';
import useApiControl, { formatDateTime } from '@/pages/Home_v_2504/hooks/useApiControl';
import useLatestValue from '@/pages/Home_v_2504/hooks/useLatestValue';

// 类型定义
interface ProblemTrendProps {
  dateType?: string;
  dateRange?: { startTime: string; endTime: string };
  dataTypeKey?: string;
  isThinLayout?: boolean;
}

const ProblemTrend: React.FC<ProblemTrendProps> = ({ 
  dateType, 
  dateRange, 
  dataTypeKey = '餐饮油烟事件',
  isThinLayout = false,
}) => {
  // 地图状态
  const { mapState } = useMapState();
  const mapStateRef = useLatestValue(mapState);
  
  // 图表数据
  const [data, setData] = useState<{ time: string; value: number }[]>([]);
  
  // 转换日期类型为API参数
  const translateDateType = useCallback((type: string) => {
    switch (type) {
      case 'year': return '1';
      case 'month': return '2';
      case 'day': return '3';
      case 'range': return '4';
      default: return '2'; // 默认月视图
    }
  }, []);
  
  // 转换时间格式 - 参考LeftContent中的translateTrendTime函数
  const translateTrendTime = useCallback((inputDate: string | number) => {
    if (typeof inputDate === 'string') {
      // 处理类似'2025-11'的格式
      if (inputDate.includes('-') && inputDate.length === 7) {
        const month = parseInt(inputDate.substring(5, 7));
        return `${month}月`;
      }
      // 处理类似'20250425'的格式
      // if (inputDate.length === 8) {
      //   const month = parseInt(inputDate.substring(4, 6));
      //   const day = parseInt(inputDate.substring(6, 8));
      //   return `${month}月${day}日`;
      // }
      // 处理YYYY-MM-DD格式
      if (inputDate.includes('-') && inputDate.length === 10) {
        const dateParts = inputDate.split('-');
        if (dateParts.length >= 3) {
          const month = parseInt(dateParts[1]);
          const day = parseInt(dateParts[2]);
          return `${month}月${day}日`;
        }
      }
      // 处理类似"03"的格式
      if (inputDate.length === 2) {
        if (inputDate === '23') {
          return '23:59:59';
        }
        return `${inputDate.padStart(2, '0')}:00:00`;
      }
      // console.log('inputDate:', inputDate);
      return inputDate.substring(0, 10);
    }
    // 处理number类型
    if (typeof inputDate === 'number') {
      if (inputDate === 23) {
        return '23:59:59';
      }
      return `${inputDate.toString().padStart(2, '0')}:00`;
    }
    return inputDate;
  }, []);
  
  // 构建API请求参数
  const buildApiParams = useCallback(() => {
    const currentMapState = mapStateRef.current;
    
    // 如果没有必要的时间参数，返回null表示不应该发起请求
    if (!currentMapState.rightPanelTime?.startTime || !currentMapState.rightPanelTime?.endTime) {
      return null;
    }
    
    // 使用当前时间类型，如果不存在则使用props或默认值
    const effectiveType = currentMapState.rightPanelTime.type || dateType || 'month';
    
    // 基础参数对象
    const params: any = {
      type: translateDateType(effectiveType)
    };
    
    // 处理日期参数
    if (effectiveType === 'range') {
      params.customizeStart = formatDateTime(currentMapState.rightPanelTime.startTime);
      params.customizeEnd = formatDateTime(currentMapState.rightPanelTime.endTime, true);
    } else {
      // 年、月、日视图使用time参数
      params.time = formatDateTime(currentMapState.rightPanelTime.startTime);
    }
    
    // 处理区域参数
    if (currentMapState.regionCode === '5101') {
      // 成都，这两个参数就不传
      params.districtCode = undefined;
      params.streetCode = undefined;
    } else if (currentMapState.regionCode.length === 6) {
      // 区县级别
      params.districtCode = currentMapState.regionCode;
    } else if (currentMapState.regionCode.length === 9) {
      // 街道级别
      params.districtCode = currentMapState.regionCode.substring(0, 6);
      params.streetCode = currentMapState.regionCode;
    }
    
    // 使用传入的dataTypeKey获取对应的subTypeCode
    params.subTypeCode = useDataType(dataTypeKey);
    
    return params;
  }, [mapStateRef, dateType, translateDateType, dataTypeKey]);

  // 使用useApiControl管理问题趋势API调用
  const eventTrendsApi = useApiControl({
    apiFunction: async (params) => {
      console.log('发起问题趋势请求，参数:', params);
      const response = await getEventTrends(params);
      
      if (response.code === 200 && response.data) {
        return response.data;
      }
      
      throw new Error('获取问题趋势数据失败');
    },
    onSuccess: (data) => {
      if (!data || !Array.isArray(data)) {
        setData([]);
        return;
      }

      const isSupplementData = false;
      // 如果是月数据，补充到月底  '2025-05-06'
      if (data[0].name.includes('-') && data[0].name.length === 10 && isSupplementData) {
        // 获取当前日期
        const today = new Date();
        const lastDay = new Date(today.getFullYear(), today.getMonth() + 1, 1);
        // console.log('lastDay:', lastDay);
        
        // 生成完整日期范围
        const fullData = [...data]; // 先复制已有数据
        
        // 从明天开始补充数据
        for (let d = new Date(today); d <= lastDay; d.setDate(d.getDate() + 1)) {
          // 跳过今天及之前的日期
          if (d <= today) continue;
          
          const dateStr = d.toISOString().slice(0, 10).replace(/-/g, '-');
          fullData.push({
            name: dateStr,
            value: '0'
          });
        }
        data = fullData;
        // console.log('补充到月底的数据:', data);
      }

      // 如果是小时数据，补充到23点
      if (data[0].name.length === 2 && isSupplementData) {
        // 获取当前小时
        const currentHour = new Date().getHours();
        // 生成完整小时范围
        const fullData = [...data]; // 先复制已有数据
        
        // 从下一小时开始补充数据
        for (let h = currentHour + 1; h <= 23; h++) {
          const hourStr = h.toString().padStart(2, '0');
          fullData.push({
            name: hourStr,
            value: '0'
          });
        }
        data = fullData;
      }
      
      // 转换接口返回的数据格式为图表需要的格式
      const formattedData = data.map((item: any) => ({
        time: translateTrendTime(item.name),
        value: parseInt(item.value) || 0
      }));
      
      console.log('问题趋势数据成功:');
      setData(formattedData);
    },
    onError: (error) => {
      console.error('获取问题趋势数据出错:', error);
      setData([]);
    },
    apiName: '问题趋势',
    debounceTime: 300,
    cacheTime: 5000 // 缓存5秒，避免频繁刷新时重复请求
  });

  // 使用 useMemo 跟踪 rightPanelTime 的实际变化
  const memoizedRightPanelTime = useMemo(() => {
    return {
      type: mapState.rightPanelTime.type,
      startTime: mapState.rightPanelTime.startTime,
      endTime: mapState.rightPanelTime.endTime
    };
  }, [
    mapState.rightPanelTime.type,
    mapState.rightPanelTime.startTime, 
    mapState.rightPanelTime.endTime
  ]);

  // 跟踪上一次的API参数，避免重复调用
  const prevApiParamsRef = useRef<string>('');

  // 在地图状态变化时加载数据
  useEffect(() => {
    const params = buildApiParams();
    
    // 如果没有必要的参数，不发送请求
    if (!params) {
      console.log('缺少必要的日期参数，不加载问题趋势数据');
      return;
    }
    
    // 参数签名，用于比较参数是否有实际变化
    const paramsSignature = JSON.stringify(params);
    
    // 检查参数是否真正变化，防止重复调用
    if (paramsSignature === prevApiParamsRef.current) {
      console.log('问题趋势参数未变化，跳过重复加载');
      return;
    }
    
    console.log('加载问题趋势数据，参数:', params);
    eventTrendsApi.callApi(params);
    
    // 更新上一次参数签名
    prevApiParamsRef.current = paramsSignature;
    
  }, [mapState.regionCode, memoizedRightPanelTime, buildApiParams, eventTrendsApi]);

  return (
    <div className={styles.container}>
      <ModuleTitleWithTabs title="问题趋势" />
      <div className={styles.chartContainer}>
        <SmoothLineChart 
          data={data} 
          unitText="单位：件"
          lineColor="rgb(136, 238, 248)"
          lineColorStop1="rgba(136, 238, 248, 0)"
          lineColorStop2="rgba(136, 238, 248, 0.36)"
          style={{ height: isThinLayout ? '278px' : '178px', width: '100%' }}
        />
      </div>
    </div>
  );
};

export default ProblemTrend; 